#
# spec file for package libimobiledevice-glue
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libimobiledevice-glue-1_0-0
%define source_date_epoch_from_changelog 1
%define clamp_mtime_to_source_date_epoch 1
%define use_source_date_epoch_as_buildtime 1
Name:           libimobiledevice-glue
Version:        1.3.1+git11.20241227
Release:        1.1
Summary:        Native protocols library for iOS devices
License:        LGPL-2.1-or-later
URL:            https://www.libimobiledevice.org
Source:         %{name}-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libplist-2.0) >= 2.3.0

%description
A library with common code used by libraries and tools around the libimobiledevice project.
It does not depend on any existing libraries from Apple.

%package -n %{libname}
Summary:        Native protocols library for iOS devices

%description -n %{libname}
A library with common code used by libraries and tools around the libimobiledevice project.
It does not depend on any existing libraries from Apple.

%package devel
Summary:        Development files for %{name}
Requires:       %{libname} = %{version}
Requires:       pkgconfig(libplist-2.0)

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q
sed -i -e '/Requires:/d' src/%{name}-1.0.pc.in
sed -i -e 's/-L${libdir}//' src/%{name}-1.0.pc.in

%build
autoreconf -fvi
%configure PACKAGE_VERSION=%{version} \
  --disable-silent-rules \
  --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc README.md
%license COPYING
%{_libdir}/%{name}-1.0.so.0*

%files devel
%{_includedir}/%{name}/
%{_libdir}/%{name}-1.0.so
%{_libdir}/pkgconfig/%{name}-1.0.pc

%changelog
* Sun Jan 12 2025 sebix@sebix.at
- Update to version 1.3.1+git11.20241227:
  * Add extern "C" guards to public headers
  * [github-actions] Bump dawidd6/action-download-artifact from 3 to 6
  * configure: Remove unused check
  * [github-actions] Run build workflow on pull_request
  * Fix unrecognized \e escape sequence
  * Fix compilation on MSVC
  * Switch to better initializer strategy
  * Change WIN32 to _WIN32 to check if running on Windows
  * socket.c: define AI_NUMERICSERV if undefined
  * socket/win32: Use calloc where applicable in getifaddrs implementation
  * sha1: Remove old commented-out code
  * Updated NEWS for release
  * Updated README
  * Update soversion for release
  * socket: Remove greater-than check for scope_id since they might not be in order
  * Update soversion for release
  * Updated NEWS for release
  * Add SHA-1, SHA-224, SHA-256, SHA-384, and SHA-512 functions to interface
  * socket: Create an IPv4 compatible IPv6 socket when NULL is passed to socket_create
  * Revert "Use updated libplist 2.5.0 API"
  * socket: Haiku compilation fixes
  * Use updated libplist 2.5.0 API
  * automake: Prevent `dist` or `distcheck` when uncommitted changes are present
  * Update NEWS for release
  * Update soversion for release
  * Add helper code to deal with NSKeyedArchiver plist data
  * [github-actions] Updated build workflow to use v3 for download-artifact
  * [github-actions] Updated build workflow to use v4 for checkout and upload-artifact
  * socket: Make sure errno is always set on error, and always return a meaningful error code
* Sat Feb 24 2024 sebix@sebix.at
- Update to version 1.1.0+git0.20240222:
  - Changes:
  * socket: Use poll() - when available - instead of select()
  * socket: Allow NULL as address for socket_create() and socket_connect()
  * win32: Remove windows.h from public headers
  * Add version function to interface
  - Bugfixes:
  * opack: Fixed 32bit buffer overflow
  * opack: Fix parsing of 32 and 64 bit packed values
  - Internal:
  * Move LIMD_GLUE_API definitions to public headers
  * socket: Conditionally compile using poll or select based on availability
  * socket: Fix select failing when the process has many file descriptors by using poll instead
  * win32: Fix external compilation using libimobiledevice-glue/thread.h
* Fri Jun  2 2023 msuchanek@suse.com
- Update to version 1.0.0+git3.20230513:
  * Set minimum required libplist version to 2.3.0
  * Remove plist-related code in favor of new libplist API
  * termcolors: Rename COLOR_* macros to FG_* due to conflict with ncurses
  * Updated README with pkg-config requirement
  * utils: Use libplist's plist_from_memory instead of duplicating format detection
  * Add support for Apple's OPACK encoding and TLV format
  * utils: Fix bad malloc result check in buffer_read_from_filename and test arguments for NULL
* Sat Oct  9 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- initial package for git repo version 20210925.
  Package is required for a revent libimobiledevice version
